@@ -7,12 +7,12 @@
 #'  extension.
 #'@param gene.symbol.col Column name of Hugo gene symbols (e.g., TP53). Default
 #'  \emph{Hugo_Symbol}.
-#'@param variant.class.col Column name of variant class information (e.g.,
-#'  \emph{Missense_Mutation}, \emph{Nonsense_Mutation}). Default is a list of
-#'  \emph{Variant_Classification} and \emph{Mutation_Class}.
-#'@param protein.change.col Column name of protein change information (e.g.,
-#'  p.K960R, G658S, L14Sfs*15). Default is a list of \emph{Protein_Change},
-#'  \emph{HGVSp_Short}.
+#'@param variant.class.col Column name for variant class information (e.g.,
+#'  \emph{Missense_Mutation}, \emph{Nonsense_Mutation}). Default is the first
+#'  match of \emph{Variant_Classification} or \emph{Mutation_Type}.
+#'@param protein.change.col Column name for protein change information (e.g.,
+#'  p.K960R, G658S, L14Sfs*15). Default is the first match of
+#'  \emph{Protein_Change} or \emph{HGVSp_Short}.
 #'@param if.parse.aa.pos if parse amino-acid position of mutations. Default is
 #'  \code{TRUE}.
 #'@param if.parse.mutation.class if parse mutation class from mutation type
@@ -35,7 +35,7 @@
 #'@export
 readMAF <- function(maf.file,
                     gene.symbol.col = "Hugo_Symbol",
-                    variant.class.col = c("Variant_Classification", "Mutation_Class"),
+                    variant.class.col = c("Variant_Classification", "Mutation_Type"),
                     protein.change.col = c("Protein_Change", "HGVSp_Short"),
                     if.parse.aa.pos = TRUE,
                     if.parse.mutation.class = TRUE,
